@@ -1,11 +1,10 @@
 #!/usr/bin/env python
+import ast
 import sys
 from typing import Callable, Dict, List, Optional, Set, Tuple, Union
 
-import codefast as cf
+import requests
 from rich import print
-import ast
-cf.logger.level = 'info'
 
 
 def extract_url(args: List[str]) -> str:
@@ -31,21 +30,19 @@ def jsoncurl():
     args = sys.argv[1:]
     url = extract_url(args)
     if url is None:
-        cf.error('url not found, url must start with http(s)')
+        print('url not found, url must start with http(s)')
         return
     json_input = extract_json_input(args)
     if not json_input:
-        cf.error('json input not found')
+        print('json input not found')
         return
 
     msg = {'url': url, 'json_input': json_input}
-    cf.info(msg)
-    resp = cf.net.post(url, json=json_input)
+    print(msg)
+    resp = requests.post(url, json=json_input)
 
     try:
         print(resp.json())
     except Exception as e:
-        cf.warning(e)
+        print(e)
         print(resp.text)
-
-
